import { createAction, props } from '@ngrx/store';

import {
  Info,
  InfoRequest as EventInfoRequest,
  InfoResponse as EventInfoResponse,
  SendRequest as SendEventRequest,
  SendResponse as SendEventResponse,
  ReadRequest,
  DelRequest,
  DelResponse,
  CancelRequest,
  CancelResponse,
  SendNotification,
  ReadNotification,
  CancelNotification,
  DelNotification,
  EventJson
} from '@ucap/protocol-event';

import {
  InfoRequest as FileInfoRequest,
  InfoResponse as FileInfoResponse,
  FileDownloadInfo,
  FileInfo
} from '@ucap/protocol-file';

/**
 * retrieve list of event
 */
export const events = createAction(
  '[ucap::chat::chatting] events',
  props<{ req: EventInfoRequest }>()
);
/**
 * Success of events request
 */
export const eventsSuccess = createAction(
  '[ucap::chat::chatting] events Success',
  props<{
    eventInfoList: Info<EventJson>[];
    res: EventInfoResponse;
    remainInfo: boolean;
  }>()
);
/**
 * Failure of events request
 */
export const eventsFailure = createAction(
  '[ucap::chat::chatting] events Failure',
  props<{ error: any }>()
);

/**
 * retrieve list of file information
 */
export const fileInfos = createAction(
  '[ucap::chat::chatting] fileInfos',
  props<{ req: FileInfoRequest }>()
);
/**
 * Success of fileInfos request
 */
export const fileInfosSuccess = createAction(
  '[ucap::chat::chatting] fileInfos Success',
  props<{
    fileInfoList: FileInfo[];
    fileInfoCheckList: FileDownloadInfo[];
    res: FileInfoResponse;
  }>()
);
/**
 * Failure of fileInfos request
 */
export const fileInfosFailure = createAction(
  '[ucap::chat::chatting] fileInfos Failure',
  props<{ error: any }>()
);

/**
 * add new event
 */
export const addEvent = createAction(
  '[ucap::chat::chatting] addEvent',
  props<{ req: FileInfoRequest }>()
);
