import { moduleMetadata } from '@storybook/angular';
import { action } from '@storybook/addon-actions';
import { linkTo } from '@storybook/addon-links';

import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

import { LogService } from '@ucap/logger';
import { Company } from '@ucap/api-external';

import { I18nService, UCAP_I18N_NAMESPACE } from '@ucap/ng-i18n';

import { AuthenticationUiModule } from '../authentication-ui.module';
import { LoginComponent } from './login.component';

export default {
  title: 'LoginComponent',
  decorators: [
    moduleMetadata({
      imports: [BrowserModule, BrowserAnimationsModule, AuthenticationUiModule],
      providers: [
        { provide: I18nService, useValue: new I18nService(new LogService({})) },
        {
          provide: UCAP_I18N_NAMESPACE,
          useValue: 'authentication'
        }
      ]
    })
  ],
  excludeStories: /.*Data$/
};

export const actionsData = {
  login: action('login')
};

export const inputData = {
  companyList: [
    { companyName: 'LG CNS', companyCode: 'GUC100' },
    { companyName: 'LG UCAP', companyCode: 'GUC101' }
  ] as Company[]
};

export const Default = () => ({
  component: LoginComponent,
  props: {
    companyList: inputData.companyList,
    login: actionsData.login
  }
});

export const InputContents = () => ({
  component: LoginComponent,
  props: {
    companyList: inputData.companyList,
    companyCode: 'GUC100',
    loginId: 'test-loginid',
    // loginPw: '111111',
    login: actionsData.login
  }
});
