import { NgModule, ModuleWithProviders } from '@angular/core';
import { CommonModule } from '@angular/common';

import { FlexLayoutModule } from '@angular/flex-layout';

import { ScrollingModule } from '@angular/cdk/scrolling';

import { MatBadgeModule } from '@angular/material/badge';
import { MatButtonModule } from '@angular/material/button';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatIconModule } from '@angular/material/icon';
import { MatRippleModule } from '@angular/material/core';
import { MatTreeModule } from '@angular/material/tree';

import { MatMenuModule } from '@angular/material/menu';
import { PerfectScrollbarModule } from 'ngx-perfect-scrollbar';

import { UiModule } from '@ucap/ng-ui';

import { I18nModule, UCAP_I18N_NAMESPACE } from '@ucap/ng-i18n';

import { ModuleConfig } from './config/module-config';
import { _MODULE_CONFIG } from './config/token';

import {
  RoomExpansionComponent,
  RoomExpansionHeaderDirective,
  RoomExpansionNodeDirective
} from './components/room-expansion.component';
import { RoomListItem01Component } from './components/room-list-item-01.component';

const COMPONENTS = [RoomExpansionComponent, RoomListItem01Component];
const DIALOGS = [];
const PIPES = [];
const DIRECTIVES = [RoomExpansionHeaderDirective, RoomExpansionNodeDirective];
const SERVICES = [];

@NgModule({
  declarations: [],
  imports: [],
  exports: []
})
export class ChatUiRootModule {}

@NgModule({
  imports: [
    CommonModule,
    FlexLayoutModule,
    ScrollingModule,

    MatBadgeModule,
    MatButtonModule,
    MatCheckboxModule,
    MatIconModule,
    MatRippleModule,
    MatTreeModule,
    MatMenuModule,

    PerfectScrollbarModule,

    I18nModule,
    UiModule
  ],
  exports: [...COMPONENTS, ...DIRECTIVES, ...PIPES],
  declarations: [...COMPONENTS, ...DIRECTIVES, ...PIPES],
  entryComponents: [...DIALOGS],
  providers: [
    {
      provide: UCAP_I18N_NAMESPACE,
      useValue: ['chat']
    }
  ]
})
export class ChatUiModule {
  public static forRoot(
    config: ModuleConfig
  ): ModuleWithProviders<ChatUiRootModule> {
    return {
      ngModule: ChatUiRootModule,
      providers: [{ provide: _MODULE_CONFIG, useValue: config }, ...SERVICES]
    };
  }
}
