import {
  Component,
  OnInit,
  OnDestroy,
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Input,
  Output,
  EventEmitter,
  ViewChild,
  ElementRef
} from '@angular/core';
import { UserInfoSS, AuthResponse } from '@ucap/protocol-query';
import { OpenProfileOptions } from '@ucap/protocol-buddy';
import { FileUploadItem } from '@ucap/api';
import { Subject } from 'rxjs';

@Component({
  selector: 'ucap-organization-profile-01',
  templateUrl: './profile-01.component.html',
  styleUrls: ['./profile-01.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class Profile01Component implements OnInit, OnDestroy {
  @Input()
  authRes: AuthResponse;

  @Input()
  userInfo: UserInfoSS;

  @Input()
  profileImageRoot: string;

  @Input()
  isMe: boolean;

  @Input()
  isBuddy: boolean;

  @Input()
  isFavorite: boolean;

  @Input()
  myMadn: string;

  @Input()
  canVideoConfernece: boolean;

  @Input()
  canBuddyToggleButton: boolean;

  @Input()
  openProfileOptions: OpenProfileOptions;

  @Output()
  toggleFavorite: EventEmitter<{
    userInfo: UserInfoSS;
    isFavorite: boolean;
  }> = new EventEmitter();

  @Output()
  toggleBuddy: EventEmitter<{
    userInfo: UserInfoSS;
    isBuddy: boolean;
  }> = new EventEmitter();

  @Output()
  openChat: EventEmitter<UserInfoSS> = new EventEmitter();

  @Output()
  sendCall: EventEmitter<string> = new EventEmitter();

  @Output()
  sendSms: EventEmitter<string> = new EventEmitter();

  @Output()
  createConference: EventEmitter<number> = new EventEmitter();

  @Output()
  sendMessage: EventEmitter<UserInfoSS> = new EventEmitter();

  @Output()
  profileImageView: EventEmitter<void> = new EventEmitter();

  @Output()
  uploadProfileImage: EventEmitter<FileUploadItem> = new EventEmitter();

  @Output()
  changeIntro: EventEmitter<string> = new EventEmitter();

  @ViewChild('profileImageFileInput', { static: false })
  profileImageFileInput: ElementRef<HTMLInputElement>;

  private ngOnDestroySubject: Subject<void>;

  constructor(private changeDetectorRef: ChangeDetectorRef) {}

  ngOnInit(): void {
    this.ngOnDestroySubject = new Subject();
  }

  ngOnDestroy(): void {
    if (!!this.ngOnDestroySubject) {
      this.ngOnDestroySubject.next();
      this.ngOnDestroySubject.complete();
    }
  }
}
