import {
  Component,
  OnInit,
  OnDestroy,
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Input,
  Output,
  EventEmitter
} from '@angular/core';
import { UserInfoSS } from '@ucap/protocol-query';
import { StatusBulkInfo } from '@ucap/protocol-status';
import { CallType } from '../types/call.type';
import { Subject } from 'rxjs';

@Component({
  selector: 'ucap-organization-profile-list-item-01',
  templateUrl: './profile-list-item-01.component.html',
  styleUrls: ['./profile-list-item-01.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class ProfileListItem01Component implements OnInit, OnDestroy {
  @Input()
  userInfo: UserInfoSS;

  @Input()
  presenceInfo?: StatusBulkInfo;

  @Input()
  profileImageRoot: string;

  @Input()
  defaultProfileImage: string;

  @Input()
  authCall = false;

  @Input()
  checkable = true;

  @Input()
  checked = false;

  @Output()
  openProfile = new EventEmitter<UserInfoSS>();

  @Output()
  changeCheck = new EventEmitter<{
    isChecked: boolean;
    userInfo: UserInfoSS;
  }>();

  @Output()
  sendCall = new EventEmitter<{
    type: CallType;
  }>();

  CallType = CallType;

  private ngOnDestroySubject: Subject<void>;

  constructor(private changeDetectorRef: ChangeDetectorRef) {}

  ngOnInit(): void {
    this.ngOnDestroySubject = new Subject();
  }

  ngOnDestroy(): void {
    if (!!this.ngOnDestroySubject) {
      this.ngOnDestroySubject.next();
      this.ngOnDestroySubject.complete();
    }
  }

  onClickOpenProfile(event: MouseEvent): void {
    event.preventDefault();
    event.stopPropagation();

    this.openProfile.emit(this.userInfo);
  }

  onChangeCheck(isChecked: boolean): void {
    this.changeCheck.emit({
      isChecked,
      userInfo: this.userInfo
    });
  }

  onSendCall(event: MouseEvent, type: CallType): void {
    event.preventDefault();
    event.stopPropagation();

    this.sendCall.emit({
      type
    });
  }
}
