import { Subject } from 'rxjs';

import {
  Component,
  OnInit,
  OnDestroy,
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Input,
  EventEmitter,
  Output
} from '@angular/core';

import { Company } from '@ucap/api-external';
import { MatSelectChange } from '@angular/material/select';

@Component({
  selector: 'ucap-organization-search-for-tenant',
  templateUrl: './search-for-tenant.component.html',
  styleUrls: ['./search-for-tenant.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class SearchForTenantComponent implements OnInit, OnDestroy {
  @Input()
  companyList: Company[];

  @Input()
  defaultCompany: string;

  @Input()
  placeholder: string;

  @Output()
  changed: EventEmitter<{
    companyCode: string;
    searchWord: string;
  }> = new EventEmitter();

  @Output()
  canceled: EventEmitter<void> = new EventEmitter();

  companyCode: string;

  private ngOnDestroySubject: Subject<void>;

  constructor(private changeDetectorRef: ChangeDetectorRef) {}

  ngOnInit(): void {
    this.ngOnDestroySubject = new Subject();

    this.companyCode = this.defaultCompany;
  }

  ngOnDestroy(): void {
    if (!!this.ngOnDestroySubject) {
      this.ngOnDestroySubject.complete();
    }
  }

  onChangeTenant(event: MatSelectChange) {
    this.companyCode = event.value;
  }
  onKeyDownEnter(searchWord: string) {
    this.changed.emit({ companyCode: this.companyCode, searchWord });
  }
  onClickCancel() {
    this.canceled.emit();
  }
}
