import { NgModule, ModuleWithProviders } from '@angular/core';
import { CommonModule } from '@angular/common';

import { FlexLayoutModule } from '@angular/flex-layout';

import { ScrollingModule } from '@angular/cdk/scrolling';

import { MatButtonModule } from '@angular/material/button';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { MatRippleModule } from '@angular/material/core';
import { MatSelectModule } from '@angular/material/select';
import { MatTreeModule } from '@angular/material/tree';

import { PerfectScrollbarModule } from 'ngx-perfect-scrollbar';

import { UiModule } from '@ucap/ng-ui';

import { ModuleConfig } from './config/module-config';
import { _MODULE_CONFIG } from './config/token';

import { Profile01Component } from './components/profile-01.component';
import { ProfileListItem01Component } from './components/profile-list-item-01.component';
import {
  ProfileListComponent,
  ProfileListNodeDirective
} from './components/profile-list.component';
import { SearchForTenantComponent } from './components/search-for-tenant.component';
import { TreeComponent } from './components/tree.component';

import { TranslatePipe } from './pipes/translate.pipe';

import { TranslateService } from './services/translate.service';

const COMPONENTS = [
  TreeComponent,
  Profile01Component,
  ProfileListItem01Component,
  ProfileListComponent,
  SearchForTenantComponent
];
const DIALOGS = [];
const PIPES = [TranslatePipe];
const DIRECTIVES = [ProfileListNodeDirective];
const SERVICES = [TranslateService];

@NgModule({
  declarations: [],
  imports: [],
  exports: []
})
export class OrganizationUiRootModule {}

@NgModule({
  imports: [
    CommonModule,
    FlexLayoutModule,
    ScrollingModule,

    MatButtonModule,
    MatCheckboxModule,
    MatFormFieldModule,
    MatIconModule,
    MatInputModule,
    MatRippleModule,
    MatSelectModule,
    MatTreeModule,

    PerfectScrollbarModule,

    UiModule
  ],
  exports: [...COMPONENTS, ...DIRECTIVES, ...PIPES],
  declarations: [...COMPONENTS, ...DIRECTIVES, ...PIPES],
  entryComponents: [...DIALOGS]
})
export class OrganizationUiModule {
  public static forRoot(
    config: ModuleConfig
  ): ModuleWithProviders<OrganizationUiRootModule> {
    return {
      ngModule: OrganizationUiRootModule,
      providers: [{ provide: _MODULE_CONFIG, useValue: config }, ...SERVICES]
    };
  }
}
